@@ -18,9 +18,6 @@ description = "PlantUML"
 java {
 	withSourcesJar()
 	withJavadocJar()
-	registerFeature("pdf") {
-		usingSourceSet(sourceSets["main"])
-	}
 }
 
 dependencies {
@@ -37,20 +34,14 @@ repositories {
 }
 
 sourceSets {
-	main {
-		java {
-			srcDirs("build/generated/sjpp")
-		}
-        resources {
-			srcDirs("../src/main/resources")
-        }
-	}
-}
-
-tasks.processResources {
-    from("../src/main/java") {
-        include("**/graphviz.dat", "**/*.svg", "**/*.png", "**/*.txt")
+  main {
+    java {
+      srcDirs("build/generated/sjpp")
     }
+    resources {
+      srcDir(rootProject.layout.projectDirectory.dir("src/main/resources"))
+    }
+  }
 }
 
 
@@ -67,7 +58,7 @@ tasks.withType<Jar>().configureEach {
 		attributes["Main-Class"] = "net.sourceforge.plantuml.Run"
 		attributes["Implementation-Version"] = archiveVersion
 		attributes["Build-Jdk-Spec"] = System.getProperty("java.specification.version")
-		from("../manifest.txt")
+		from(rootProject.layout.projectDirectory.file("manifest.txt"))
 	}
 
 	// source sets for java and resources are on "src", only put once into the jar
@@ -158,16 +149,18 @@ publishing {
 		}
 	}
 	repositories {
-		maven {
-			name = "OSSRH"
-			val releasesRepoUrl = "https://oss.sonatype.org/service/local/staging/deploy/maven2/"
-			val snapshotsRepoUrl = "https://oss.sonatype.org/content/repositories/snapshots/"
-			url = uri(if (version.toString().endsWith("SNAPSHOT")) snapshotsRepoUrl else releasesRepoUrl)
-			credentials {
-				username = System.getenv("OSSRH_USERNAME")
-				password = System.getenv("OSSRH_PASSWORD")
-			}
-		}
+	    maven {
+            name = "CentralPortal"
+            val releasesRepoUrl = "https://ossrh-staging-api.central.sonatype.com/service/local/staging/deploy/maven2/"
+            val snapshotsRepoUrl = "https://central.sonatype.com/repository/maven-snapshots/"
+            url = uri(
+                if (version.toString().endsWith("SNAPSHOT")) snapshotsRepoUrl else releasesRepoUrl
+            )
+            credentials {
+                username = System.getenv("CENTRAL_USERNAME")
+                password = System.getenv("CENTRAL_PASSWORD")
+            }
+        }
 	}
 }
 
