@@ -59,6 +59,7 @@ import net.sourceforge.plantuml.cli.CliAction;
 import net.sourceforge.plantuml.cli.CliFlag;
 import net.sourceforge.plantuml.cli.CliOptions;
 import net.sourceforge.plantuml.cli.CliParser;
+import net.sourceforge.plantuml.cli.CliParsingException;
 import net.sourceforge.plantuml.cli.ErrorStatus;
 import net.sourceforge.plantuml.cli.Exit;
 import net.sourceforge.plantuml.cli.GlobalConfig;
@@ -119,9 +120,10 @@ public class Run {
 			Log.info(() -> "java.awt.headless set as '" + javaAwtHeadless + "'");
 
 		final ErrorStatus errorStatus = ErrorStatus.init();
-		final CliOptions option = CliParser.parse(argsArray);
+		CliOptions option = null;
 
 		try {
+			option = CliParser.parse(argsArray);
 
 			final String timeout = option.getString(CliFlag.TIMEOUT);
 			if (timeout != null && timeout.matches("\\d+"))
@@ -218,14 +220,17 @@ public class Run {
 			else
 				runner.processInputsInParallel();
 
+		} catch (CliParsingException e) {
+			System.err.println(e.getMessage());
+			Exit.exit(42);
 		} finally {
-			if (option.isTrue(CliFlag.DURATION)) {
+			if (option != null && option.isTrue(CliFlag.DURATION)) {
 				final double duration = (System.currentTimeMillis() - start) / 1000.0;
 				Log.error("Duration = " + duration + " seconds");
 			}
 		}
 
-		if (errorStatus.hasError() || errorStatus.isEmpty())
+		if (option != null && (errorStatus.hasError() || errorStatus.isEmpty()))
 			option.getStdrpt().finalMessage(errorStatus);
 
 		if (errorStatus.hasError())
@@ -558,6 +563,8 @@ public class Run {
 		}
 	}
 
+	private static final String META_HEADER_NEW = "<?plantuml-src ";
+
 	private static void extractMetadata(File f) throws IOException {
 		System.out.println("------------------------");
 		System.out.println(f);
@@ -565,17 +572,9 @@ public class Run {
 		if (f.getName().endsWith(".svg")) {
 			final SFile file = SFile.fromFile(f);
 			final String svg = FileUtils.readFile(file);
-			final int idx = svg.lastIndexOf(SvgGraphics.META_HEADER);
-			if (idx > 0) {
-				String part = svg.substring(idx + SvgGraphics.META_HEADER.length());
-				final int idxEnd = part.indexOf("]");
-				if (idxEnd > 0) {
-					part = part.substring(0, idxEnd);
-					part = part.replace("- -", "--");
-					final String decoded = TranscoderUtil.getDefaultTranscoderProtected().decode(part);
-					System.out.println(decoded);
-				}
-			}
+			final String decoded = extractMetadataFromSvg(svg);
+			if (decoded != null)
+				System.out.println(decoded);
 		} else {
 			final String data = new MetadataTag(f, "plantuml").getData();
 			System.out.println(data);
@@ -583,4 +582,29 @@ public class Run {
 		System.out.println("------------------------");
 	}
 
+	private static String extractMetadataFromSvg(String svg) throws NoPlantumlCompressionException {
+		// New format: <?plantuml-src ...?>
+		final int idxNew = svg.lastIndexOf(META_HEADER_NEW);
+		if (idxNew > 0) {
+			String part = svg.substring(idxNew + META_HEADER_NEW.length());
+			final int idxEnd = part.indexOf("?>");
+			if (idxEnd > 0) {
+				part = part.substring(0, idxEnd);
+				return TranscoderUtil.getDefaultTranscoderProtected().decode(part);
+			}
+		}
+		// Old format: <!--SRC=[...]-->
+		final int idxOld = svg.lastIndexOf(SvgGraphics.META_HEADER);
+		if (idxOld > 0) {
+			String part = svg.substring(idxOld + SvgGraphics.META_HEADER.length());
+			final int idxEnd = part.indexOf("]");
+			if (idxEnd > 0) {
+				part = part.substring(0, idxEnd);
+				part = part.replace("- -", "--");
+				return TranscoderUtil.getDefaultTranscoderProtected().decode(part);
+			}
+		}
+		return null;
+	}
+
 }
