@@ -87,7 +87,7 @@ public enum CliFlag {
 	TEST_DOT("--check-graphviz", aliases(DEPRECATED("-testdot")), Arity.UNARY_IMMEDIATE_ACTION,
 			OptionPrint::printCheckGraphviz),
 
-	@CliFlagDoc(value = "Start internal HTTP server for rendering (default port : 4242)", usage = "--http-server[:<port>]", level = 0)
+	@CliFlagDoc(value = "Start internal HTTP server for rendering (default port : 8080)", usage = "--http-server[:<port>]", level = 0)
 	PICOWEB("--http-server", aliases(DEPRECATED("-picoweb")), Arity.UNARY_OPTIONAL_COLON),
 
 	// Input & preprocessing:
@@ -106,19 +106,19 @@ public enum CliFlag {
 	@CliDefaultValue("0")
 	PIPE_IMAGE_INDEX("--pipe-image-index", aliases(DEPRECATED("-pipeimageindex")), Arity.BINARY_NEXT_ARGUMENT_VALUE),
 
-	@CliFlagDoc(value = "Define a preprocessing variable (equivalent to '!define <var> <value>')", usage = "-D<var>=<value>,\n--define <VAR>=<value>", level = 0)
+	@CliFlagDoc(value = "Define a preprocessing variable (equivalent to '!define <var> <value>')", usage = "-d, --define <VAR>=<value>", level = 0)
 	DEFINE("-D", Arity.UNARY_INLINE_KEY_OR_KEY_VALUE), //
 	DEFINE_LONG("--define", Arity.BINARY_NEXT_ARGUMENT_VALUE), //
 
-	@CliFlagDoc(value = "Include external file (as with '!include <file>')", usage = "-I<file>,\n--include <file>", level = 1)
+	@CliFlagDoc(value = "Include external file (as with '!include <file>')", usage = "-I, --include <file>", level = 1)
 	INCLUDE("-I", Arity.UNARY_INLINE_KEY_OR_KEY_VALUE), //
 	INCLUDE_LONG("--include", Arity.BINARY_NEXT_ARGUMENT_VALUE), //
 
-	@CliFlagDoc(value = "Set pragma (equivalent to '!pragma <key> <value>')", usage = "-P<key>=<value>,\n--pragma <key>=<value>", level = 1)
+	@CliFlagDoc(value = "Set pragma (equivalent to '!pragma <key> <value>')", usage = "-P, --pragma <key>=<value>", level = 1)
 	PRAGMA("-P", Arity.UNARY_INLINE_KEY_OR_KEY_VALUE), //
 	PRAGMA_LONG("--pragma", Arity.BINARY_NEXT_ARGUMENT_VALUE), //
 
-	@CliFlagDoc(value = "Set skin parameter (equivalent to 'skinparam <key> <value>')", usage = "-S<key>=<value>,\n--skinparam <key>=<value>", level = 1)
+	@CliFlagDoc(value = "Set skin parameter (equivalent to 'skinparam <key> <value>')", usage = "--skinparam <key>=<value>", level = 1)
 	SKINPARAM("-S", Arity.UNARY_INLINE_KEY_OR_KEY_VALUE), //
 	SKINPARAM_LONG("--skinparam", Arity.BINARY_NEXT_ARGUMENT_VALUE), //
 
@@ -229,7 +229,7 @@ public enum CliFlag {
 
 	// Output format (choose one)
 
-	@CliFlagDoc(value = "Set the output format for generated diagrams\n(e.g. png, svg, pdf, eps, latex, txt, utxt, obfuscate, preproc...)", level = 0, usage = "-f <name>, --format <name>", newGroup = "Output format (choose one)")
+	@CliFlagDoc(value = "Set the output format for generated diagrams\n(e.g. png, svg, pdf, eps, latex, txt, utxt, obfuscate, preproc...)", level = 0, usage = "-f, --format <name>", newGroup = "Output format (choose one)")
 	FORMAT("--format", aliases("-f"), Arity.BINARY_NEXT_ARGUMENT_VALUE),
 	
 	@CliFlagDoc(value = "Generate images in EPS format", level = 0, newGroup = "Available formats")
