@@ -161,7 +161,7 @@ public class CliParsed {
 
 	}
 
-	public static CliParsed parse(String... args) {
+	public static CliParsed parse(String... args) throws CliParsingException {
 		final CliParsed result = new CliParsed();
 		for (final Peeker<String> peeker = PeekerUtils.peeker(Arrays.asList(args)); peeker.peek(0) != null; peeker
 				.jump()) {
@@ -196,6 +196,9 @@ public class CliParsed {
 						s = peeker.peek(0);
 					}
 
+					if (s == null)
+						throw new CliParsingException(flag, "missing value");
+
 					final int eqIndex = s.indexOf('=');
 					final String k = eqIndex < 0 ? s : s.substring(0, eqIndex);
 					final String v = eqIndex < 0 ? null : s.substring(eqIndex + 1);
