@@ -39,7 +39,7 @@ import java.io.IOException;
 
 public class CliParser {
 
-	public static CliOptions parse(String... arg) throws InterruptedException, IOException {
+	public static CliOptions parse(String... arg) throws InterruptedException, IOException, CliParsingException {
 		return new CliOptions(arg);
 	}
 
