@@ -61,6 +61,7 @@ import net.sourceforge.plantuml.descdiagram.command.CommandLinkElement;
 import net.sourceforge.plantuml.descdiagram.command.CommandNewpage;
 import net.sourceforge.plantuml.descdiagram.command.CommandPackageWithUSymbol;
 import net.sourceforge.plantuml.descdiagram.command.CommandTogether;
+import net.sourceforge.plantuml.nio.PathSystem;
 import net.sourceforge.plantuml.objectdiagram.command.CommandCreateJson;
 import net.sourceforge.plantuml.objectdiagram.command.CommandCreateJsonSingleLine;
 import net.sourceforge.plantuml.objectdiagram.command.CommandCreateMap;
@@ -72,8 +73,8 @@ import net.sourceforge.plantuml.skin.UmlDiagramType;
 public class DescriptionDiagramFactory extends PSystemCommandFactory {
 
 	@Override
-	public DescriptionDiagram createEmptyDiagram(UmlSource source, Previous previous,
-			PreprocessingArtifact preprocessing) {
+	public DescriptionDiagram createEmptyDiagram(PathSystem pathSystem, UmlSource source,
+			Previous previous, PreprocessingArtifact preprocessing) {
 		return new DescriptionDiagram(source, previous, preprocessing);
 	}
 
