@@ -43,6 +43,7 @@ import net.sourceforge.plantuml.command.CommonCommands;
 import net.sourceforge.plantuml.command.PSystemCommandFactory;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
+import net.sourceforge.plantuml.nio.PathSystem;
 import net.sourceforge.plantuml.preproc.PreprocessingArtifact;
 import net.sourceforge.plantuml.skin.UmlDiagramType;
 
@@ -63,7 +64,7 @@ public class PSystemEbnfFactory extends PSystemCommandFactory {
 	}
 
 	@Override
-	public PSystemEbnf createEmptyDiagram(UmlSource source, Previous previous, PreprocessingArtifact preprocessing) {
+	public PSystemEbnf createEmptyDiagram(PathSystem pathSystem, UmlSource source, Previous previous, PreprocessingArtifact preprocessing) {
 		return new PSystemEbnf(source, preprocessing);
 	}
 
