@@ -69,15 +69,15 @@ public class CommandCreoleEmoji implements Command {
 		if (m.find() == false)
 			throw new IllegalStateException();
 
-		final String colorName1 = m.group(2);
-		final String emoji = m.group(3);
-		final double scale = Parser.getScale(m.group(4), 1);
-		final String colorName2 = Parser.getColor(m.group(4));
-		
-		final String colorName = colorName1 == null ? colorName2 : colorName1;
+		if (stripe != null) {
+			final String colorName1 = m.group(2);
+			final String emoji = m.group(3);
+			final double scale = Parser.getScale(m.group(4), 1);
+			final String colorName2 = Parser.getColor(m.group(4));
+			final String colorName = colorName1 == null ? colorName2 : colorName1;
+			stripe.addEmoji(emoji, scale, colorName);
+		}
 
-
-		stripe.addEmoji(emoji, scale, colorName);
 		return line.substring(m.group(1).length());
 	}
 
