@@ -502,4 +502,203 @@ public class DotPath implements UShape, Moveable {
 		this.codeLine = codeLine;
 	}
 
+	/**
+	 * Round corners in orthogonal paths by replacing sharp 90-degree corners
+	 * with smooth curves.
+	 *
+	 * @param radius Corner radius in pixels
+	 */
+	public void muteToRoundOrthogonalPaths(double radius) {
+		if (radius <= 0 || beziers.size() < 2)
+			return;
+
+		if (!isOrthogonalPathInternal())
+			return;
+
+		// Build list of all points in the path
+		final List<XPoint2D> points = new ArrayList<>();
+		if (beziers.size() > 0) {
+			points.add(beziers.get(0).getP1());
+			for (XCubicCurve2D bez : beziers)
+				points.add(bez.getP2());
+		}
+
+		if (points.size() < 3)
+			return;
+
+		// Detect corners
+		final List<Integer> corners = detectCorners(points);
+		if (corners.isEmpty())
+			return;
+
+		// Build new path with rounded corners
+		final List<XPoint2D> newPoints = buildRoundedPath(points, corners, radius);
+
+		// Build beziers from new points
+		final List<XCubicCurve2D> newBeziers = buildBeziersFromPoints(newPoints, points, corners);
+
+		// Replace beziers
+		beziers.clear();
+		beziers.addAll(newBeziers);
+	}
+
+	/**
+	 * Detect corners in the path where segments meet at 90 degrees
+	 */
+	private List<Integer> detectCorners(List<XPoint2D> points) {
+		final List<Integer> corners = new ArrayList<>();
+		for (int i = 1; i < points.size() - 1; i++) {
+			final XPoint2D prev = points.get(i - 1);
+			final XPoint2D curr = points.get(i);
+			final XPoint2D next = points.get(i + 1);
+
+			// Calculate direction vectors
+			double dx1 = curr.getX() - prev.getX();
+			double dy1 = curr.getY() - prev.getY();
+			double dx2 = next.getX() - curr.getX();
+			double dy2 = next.getY() - curr.getY();
+
+			final double len1 = Math.sqrt(dx1 * dx1 + dy1 * dy1);
+			final double len2 = Math.sqrt(dx2 * dx2 + dy2 * dy2);
+
+			if (len1 < 0.01 || len2 < 0.01)
+				continue;
+
+			// Normalize
+			dx1 /= len1;
+			dy1 /= len1;
+			dx2 /= len2;
+			dy2 /= len2;
+
+			// Check if perpendicular (dot product ≈ 0 for 90 degrees)
+			final double dotProduct = dx1 * dx2 + dy1 * dy2;
+			if (Math.abs(dotProduct) < 0.1)
+				corners.add(i);
+		}
+		return corners;
+	}
+
+	/**
+	 * Build new path with truncated corners ready for rounding
+	 */
+	private List<XPoint2D> buildRoundedPath(List<XPoint2D> points, List<Integer> corners, double radius) {
+		final List<XPoint2D> newPoints = new ArrayList<>();
+		newPoints.add(points.get(0)); // Start point
+
+		for (int i = 1; i < points.size() - 1; i++) {
+			if (corners.contains(i)) {
+				// This is a corner - add truncated points around it
+				final XPoint2D prev = points.get(i - 1);
+				final XPoint2D curr = points.get(i);
+				final XPoint2D next = points.get(i + 1);
+
+				// Direction vectors
+				double dx1 = curr.getX() - prev.getX();
+				double dy1 = curr.getY() - prev.getY();
+				double dx2 = next.getX() - curr.getX();
+				double dy2 = next.getY() - curr.getY();
+
+				final double len1 = Math.sqrt(dx1 * dx1 + dy1 * dy1);
+				final double len2 = Math.sqrt(dx2 * dx2 + dy2 * dy2);
+
+				dx1 /= len1;
+				dy1 /= len1;
+				dx2 /= len2;
+				dy2 /= len2;
+
+				final double truncDist1 = Math.min(radius, len1 / 2);
+				final double truncDist2 = Math.min(radius, len2 / 2);
+
+				// Add point before corner
+				final double beforeX = curr.getX() - dx1 * truncDist1;
+				final double beforeY = curr.getY() - dy1 * truncDist1;
+				newPoints.add(new XPoint2D(beforeX, beforeY));
+
+				// Add the corner point itself (will be used as control point)
+				newPoints.add(curr);
+
+				// Add point after corner
+				final double afterX = curr.getX() + dx2 * truncDist2;
+				final double afterY = curr.getY() + dy2 * truncDist2;
+				newPoints.add(new XPoint2D(afterX, afterY));
+			} else {
+				// Regular point
+				newPoints.add(points.get(i));
+			}
+		}
+
+		newPoints.add(points.get(points.size() - 1)); // End point
+		return newPoints;
+	}
+
+	/**
+	 * Build bezier curves from the rounded path points
+	 */
+	private List<XCubicCurve2D> buildBeziersFromPoints(List<XPoint2D> newPoints, List<XPoint2D> originalPoints,
+			List<Integer> corners) {
+		final List<XCubicCurve2D> newBeziers = new ArrayList<>();
+		for (int i = 0; i < newPoints.size() - 1; i++) {
+			final XPoint2D p1 = newPoints.get(i);
+			final XPoint2D p2 = newPoints.get(i + 1);
+
+			// Check if next point is a control point (corner)
+			if (i + 2 < newPoints.size()) {
+				final XPoint2D p3 = newPoints.get(i + 2);
+
+				// Check if p2 was originally a corner point
+				boolean isCornerControl = false;
+				for (int cornerIdx : corners) {
+					if (originalPoints.get(cornerIdx).equals(p2)) {
+						isCornerControl = true;
+						break;
+					}
+				}
+
+				if (isCornerControl) {
+					// Create rounded corner with p2 as control point
+					// For circular arc approximation
+					final double dx1 = p2.getX() - p1.getX();
+					final double dy1 = p2.getY() - p1.getY();
+					final double dx2 = p3.getX() - p2.getX();
+					final double dy2 = p3.getY() - p2.getY();
+					final double len1 = Math.sqrt(dx1 * dx1 + dy1 * dy1);
+					final double len2 = Math.sqrt(dx2 * dx2 + dy2 * dy2);
+
+					final double controlDist = Math.min(len1, len2) * 0.55228;
+
+					final double ctrl1X = p1.getX() + (dx1 / len1) * controlDist;
+					final double ctrl1Y = p1.getY() + (dy1 / len1) * controlDist;
+					final double ctrl2X = p3.getX() - (dx2 / len2) * controlDist;
+					final double ctrl2Y = p3.getY() - (dy2 / len2) * controlDist;
+
+					newBeziers.add(new XCubicCurve2D(p1.getX(), p1.getY(), ctrl1X, ctrl1Y,
+							ctrl2X, ctrl2Y, p3.getX(), p3.getY()));
+
+					i++; // Skip the control point and the next point
+					continue;
+				}
+			}
+
+			// Regular straight segment
+			newBeziers.add(new XCubicCurve2D(p1.getX(), p1.getY(), p1.getX(), p1.getY(),
+					p2.getX(), p2.getY(), p2.getX(), p2.getY()));
+		}
+		return newBeziers;
+	}
+
+	/**
+	 * Check if path consists of orthogonal (horizontal/vertical) segments
+	 */
+	private boolean isOrthogonalPathInternal() {
+		for (XCubicCurve2D curve : beziers) {
+			final double dx = Math.abs(curve.x2 - curve.x1);
+			final double dy = Math.abs(curve.y2 - curve.y1);
+
+			// Check if segment is either horizontal or vertical (not diagonal)
+			if (dx > 0.1 && dy > 0.1)
+				return false;
+		}
+		return true;
+	}
+
 }
