@@ -43,6 +43,7 @@ import net.sourceforge.plantuml.command.CommonCommands;
 import net.sourceforge.plantuml.command.PSystemCommandFactory;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
+import net.sourceforge.plantuml.nio.PathSystem;
 import net.sourceforge.plantuml.preproc.PreprocessingArtifact;
 import net.sourceforge.plantuml.skin.UmlDiagramType;
 
@@ -64,7 +65,7 @@ public class PSystemSaltFactory extends PSystemCommandFactory {
 	}
 
 	@Override
-	public PSystemSalt createEmptyDiagram(UmlSource source, Previous previous, PreprocessingArtifact preprocessing) {
+	public PSystemSalt createEmptyDiagram(PathSystem pathSystem, UmlSource source, Previous previous, PreprocessingArtifact preprocessing) {
 		final PSystemSalt result = new PSystemSalt(source, preprocessing);
 		if (getDiagramType() == DiagramType.SALT) {
 			result.setIamSalt(true);
