@@ -27,7 +27,7 @@ class RunFlagThemeTest extends AbstractCliTest {
 		final String content = new String(Files.readAllBytes(svgFile), java.nio.charset.StandardCharsets.UTF_8);
 
 		assertTrue(content.contains("<svg"));
-		assertTrue(content.contains("Cannot load foo"));
+		assertTrue(content.contains("Cannot load theme foo"));
 		assertTrue(content.contains("!theme foo"));
 	}
 
