@@ -4,8 +4,10 @@ import net.sourceforge.plantuml.TitledDiagram;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.parallel.Isolated;
 
 @ExtendWith(GraphvizRequiredTestFilter.class)
+@Isolated
 public class SvekSvgTest extends SvgTest {
 
 	private boolean originalForceSmetanaSetting;
